# Edit this configuration file to define what should be installed on
# your system.  Help is available in the configuration.nix(5) man page
# and in the NixOS manual (accessible by running ‘nixos-help’).

{ config, pkgs, ... }:

{
  system.autoUpgrade.enable = true;

  # boot
  boot.loader.systemd-boot.enable = true;
  boot.loader.efi.canTouchEfiVariables = true;
  # zfs
  boot.initrd.supportedFilesystems = ["zfs"]; # boot from zfs
  boot.supportedFilesystems = [ "zfs" ];
  #boot.kernelParams = [ "nohibernate" ];
  services.zfs.autoScrub.enable = true;

  networking.useNetworkd = true;
  networking.useDHCP = false;
  services.openssh.enable = true;

  time.timeZone = "Europe/Berlin";
  i18n.defaultLocale = "en_IE.UTF-8";
  console = {
    font = "Lat2-Terminus16";
    keyMap = "de";
  };

  environment.systemPackages = with pkgs; [
    python3
    killall
    htop
    mosh
    git
    git-lfs
    tig
    figlet
    grml-zsh-config 
    tmux
    neovim
    xh
    liboping
    mtr
    home-manager
  ];

  # zsh
  users.defaultUserShell = pkgs.zsh;
  programs.zsh.enable = true;
  programs.zsh.autosuggestions.enable = true;
  programs.zsh.syntaxHighlighting.enable = true;
  programs.zsh.interactiveShellInit = ''
    source ${pkgs.grml-zsh-config}/etc/zsh/zshrc
  '';
  programs.zsh.promptInit = "";
}

